==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiPage/ParagraphNode.pm <==
#
# WiKicker
#
#  ParagraphNode.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: ParagraphNode.pm,v 1.2 2003/06/12 04:11:02 naney Exp $
#
#

package WiKicker::WikiPage::ParagraphNode;

use strict;
use WiKicker::WikiPage::Acceptor;
use WiKicker::WikiPage::Node;

use vars qw(@ISA);

@ISA = qw(WiKicker::WikiPage::Acceptor WiKicker::WikiPage::Node);  

sub to_string {
  my $self = shift;

  return join('', map { $_->to_string } $self->nodes);
}

sub to_unarmor_string {
  my $self = shift;

  return join('', map { $_->to_unarmor_string } $self->nodes);
}

sub is_index_or_form_only {
  my $self = shift;

  my @nodes = $self->nodes;

  return 0 if @nodes > 2;

  if (@nodes == 2) {
    return 0 unless ref $nodes[1] eq 'WiKicker::WikiPage::TextNode';
    return 0 unless $nodes[1]->to_string =~ /^\s*\n?$/;
  }

  return 0 unless ref $nodes[0] eq 'WiKicker::WikiPage::BracketNameNode';
  return 0 unless ($nodes[0]->wri)->isa('WiKicker::WRI::RWRN');

  my $scheme = $nodes[0]->wri->scheme;
  return $scheme eq 'index' || $scheme eq 'form';
}


1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiPage/ParagraphNode.pm <==
#
# WiKicker
#
#  ParagraphNode.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: ParagraphNode.pm,v 1.3 2004/06/11 14:50:39 naney Exp $
#
#

package WiKicker::WikiPage::ParagraphNode;

use strict;
use WiKicker::WikiPage::Acceptor qw(:accept);
use WiKicker::WikiPage::Node;

use vars qw(@ISA);

@ISA = qw(WiKicker::WikiPage::Node);

sub to_string {
  my $self = shift;

  return join('', map { $_->to_string } $self->nodes);
}

sub to_unarmor_string {
  my $self = shift;

  return join('', map { $_->to_unarmor_string } $self->nodes);
}

sub is_index_or_form_only {
  my $self = shift;

  my $nodes = $self->child_nodes;

  return 0 if scalar(@{$nodes}) > 2;

  if (scalar(@{$nodes}) == 2) {
    return 0 unless ref $nodes->[1] eq 'WiKicker::WikiPage::TextNode';
    return 0 unless $nodes->[1]->to_string =~ /^\s*\n?$/;
  }

  return 0 unless ref $nodes->[0] eq 'WiKicker::WikiPage::BracketNameNode';
  return 0 unless ($nodes->[0]->wri)->isa('WiKicker::WRI::RWRN');

  my $scheme = $nodes->[0]->wri->scheme;
  return $scheme eq 'index' || $scheme eq 'form';
}


1;
